pub struct ChequePresentmentNotificationV01 {
pub grp_hdr: GroupHeader1031,
pub chq: Cheque131,
}Fields
grp_hdr: GroupHeader1031chq: Cheque131Trait Implementations
Sourceimpl Clone for ChequePresentmentNotificationV01
impl Clone for ChequePresentmentNotificationV01
Sourcefn clone(&self) -> ChequePresentmentNotificationV01
fn clone(&self) -> ChequePresentmentNotificationV01
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ChequePresentmentNotificationV01
impl Default for ChequePresentmentNotificationV01
Sourcefn default() -> ChequePresentmentNotificationV01
fn default() -> ChequePresentmentNotificationV01
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ChequePresentmentNotificationV01
impl<'de> Deserialize<'de> for ChequePresentmentNotificationV01
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ChequePresentmentNotificationV01
impl PartialEq for ChequePresentmentNotificationV01
Sourcefn eq(&self, other: &ChequePresentmentNotificationV01) -> bool
fn eq(&self, other: &ChequePresentmentNotificationV01) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Validate for ChequePresentmentNotificationV01
impl Validate for ChequePresentmentNotificationV01
Sourcefn validate(
&self,
path: &str,
config: &ParserConfig,
collector: &mut ErrorCollector,
)
fn validate( &self, path: &str, config: &ParserConfig, collector: &mut ErrorCollector, )
Validate the instance and collect errors with path information
impl StructuralPartialEq for ChequePresentmentNotificationV01