pub struct ProxyAccountIdentification1 {
pub tp: Option<ProxyAccountType1Choice>,
pub id: String,
}Fields
tp: Option<ProxyAccountType1Choice>id: StringTrait Implementations
Sourceimpl Clone for ProxyAccountIdentification1
impl Clone for ProxyAccountIdentification1
Sourcefn clone(&self) -> ProxyAccountIdentification1
fn clone(&self) -> ProxyAccountIdentification1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProxyAccountIdentification1
impl Debug for ProxyAccountIdentification1
Sourceimpl Default for ProxyAccountIdentification1
impl Default for ProxyAccountIdentification1
Sourcefn default() -> ProxyAccountIdentification1
fn default() -> ProxyAccountIdentification1
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProxyAccountIdentification1
impl<'de> Deserialize<'de> for ProxyAccountIdentification1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProxyAccountIdentification1
impl PartialEq for ProxyAccountIdentification1
Sourcefn eq(&self, other: &ProxyAccountIdentification1) -> bool
fn eq(&self, other: &ProxyAccountIdentification1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Validate for ProxyAccountIdentification1
impl Validate for ProxyAccountIdentification1
Sourcefn validate(
&self,
path: &str,
config: &ParserConfig,
collector: &mut ErrorCollector,
)
fn validate( &self, path: &str, config: &ParserConfig, collector: &mut ErrorCollector, )
Validate the instance and collect errors with path information
impl StructuralPartialEq for ProxyAccountIdentification1